@@ -17,8 +17,7 @@ class FileWatchdog(FileSystemEventHandler):
         :param callback: the callback to invoke when changes are detected
         """
         self.file_path = os.path.realpath(file_path)
-        # https://github.com/python/mypy/issues/708
-        self.callback = callback  # type: ignore[assignment]
+        self.callback = callback
 
         self._observer = Observer()
         self._observer.schedule(event_handler=self, path=os.path.dirname(file_path))
